@@ -1,7 +1,7 @@
 package Complete::Util;
 
-our $DATE = '2015-03-18'; # DATE
-our $VERSION = '0.25'; # VERSION
+our $DATE = '2015-03-30'; # DATE
+our $VERSION = '0.26'; # VERSION
 
 use 5.010001;
 use strict;
@@ -474,8 +474,17 @@ sub combine_answers {
             $encounter_hash++;
             $add_words->($ans->{words} // []);
             for (keys %$ans) {
-                next if $_ eq 'words';
-                $final->{$_} = $ans->{$_};
+                if ($_ eq 'words') {
+                    next;
+                } elsif ($_ eq 'static') {
+                    if (exists $final->{$_}) {
+                        $final->{$_} &&= $ans->{$_};
+                    } else {
+                        $final->{$_} = $ans->{$_};
+                    }
+                } else {
+                    $final->{$_} = $ans->{$_};
+                }
             }
         }
     }
@@ -501,7 +510,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.25 of Complete::Util (from Perl distribution Complete-Util), released on 2015-03-18.
+This document describes version 0.26 of Complete::Util (from Perl distribution Complete-Util), released on 2015-03-30.
 
 =head1 DESCRIPTION
 
@@ -731,7 +740,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete-U
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Complete-Util>.
+Source repository is at L<https://github.com/sharyanto/perl-SHARYANTO-Complete-Util>.
 
 =head1 BUGS
 
